==> gradle-0.8-src.zip: gradle-0.8/subprojects/gradle-core/src/test/groovy/org/gradle/api/internal/artifacts/ivyservice/DefaultPublishOptionsFactoryTest.java <==
/*
 * Copyright 2007-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api.internal.artifacts.ivyservice;

import org.apache.ivy.core.publish.PublishOptions;
import org.gradle.api.artifacts.PublishInstruction;
import org.gradle.util.WrapUtil;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.Assert.assertThat;
import org.junit.Before;
import org.junit.Test;

import java.io.File;

/**
 * @author Hans Dockter
 */
public class DefaultPublishOptionsFactoryTest {
    private DefaultPublishOptionsFactory publishOptionsFactory;
    private static final String TEST_CONF = "conf1";

    @Before
    public void setUp() {
        publishOptionsFactory = new DefaultPublishOptionsFactory();
    }

    @Test
    public void testCreatePublishOptionsWithUploadModuleDescriptorTrue() {
        File testIvyFile = new File("testFile");
        PublishInstruction publishInstruction = new PublishInstruction(true, testIvyFile);
        PublishOptions publishOptions = publishOptionsFactory.createPublishOptions(WrapUtil.toSet(TEST_CONF), publishInstruction);
        assertThat(publishOptions.getSrcIvyPattern(), equalTo(testIvyFile.getAbsolutePath()));
        checkCommonValues(publishOptions);
    }

    @Test
    public void testCreatePublishOptionsWithUploadModuleDescriptorFalse() {
        PublishInstruction publishInstruction = new PublishInstruction();
        PublishOptions publishOptions = publishOptionsFactory.createPublishOptions(WrapUtil.toSet(TEST_CONF), publishInstruction);
        assertThat(publishOptions.getSrcIvyPattern(), equalTo(null));
        checkCommonValues(publishOptions);
    }

    private void checkCommonValues(PublishOptions publishOptions) {
        assertThat(publishOptions.getConfs(), equalTo(WrapUtil.toArray(TEST_CONF)));
        assertThat(publishOptions.isOverwrite(), equalTo(true));
    }
}

==> gradle-0.9-rc-3-src.zip: gradle-0.9-rc-3/subprojects/gradle-core/src/test/groovy/org/gradle/api/internal/artifacts/ivyservice/DefaultPublishOptionsFactoryTest.java <==
/*
 * Copyright 2007-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.gradle.api.internal.artifacts.ivyservice;

import org.apache.ivy.core.publish.PublishOptions;
import org.gradle.util.WrapUtil;
import static org.hamcrest.Matchers.equalTo;
import static org.junit.Assert.assertThat;
import org.junit.Before;
import org.junit.Test;

import java.io.File;

/**
 * @author Hans Dockter
 */
public class DefaultPublishOptionsFactoryTest {
    private DefaultPublishOptionsFactory publishOptionsFactory;
    private static final String TEST_CONF = "conf1";

    @Before
    public void setUp() {
        publishOptionsFactory = new DefaultPublishOptionsFactory();
    }

    @Test
    public void testCreatePublishOptionsWithUploadModuleDescriptorTrue() {
        File someDescriptorDestination = new File("somePath");
        PublishOptions publishOptions = publishOptionsFactory.createPublishOptions(WrapUtil.toSet(TEST_CONF), someDescriptorDestination);
        assertThat(publishOptions.getSrcIvyPattern(), equalTo(someDescriptorDestination.getAbsolutePath()));
        checkCommonValues(publishOptions);
    }

    @Test
    public void testCreatePublishOptionsWithUploadModuleDescriptorFalse() {
        PublishOptions publishOptions = publishOptionsFactory.createPublishOptions(WrapUtil.toSet(TEST_CONF), null);
        assertThat(publishOptions.getSrcIvyPattern(), equalTo(null));
        checkCommonValues(publishOptions);
    }

    private void checkCommonValues(PublishOptions publishOptions) {
        assertThat(publishOptions.getConfs(), equalTo(WrapUtil.toArray(TEST_CONF)));
        assertThat(publishOptions.isOverwrite(), equalTo(true));
    }
}
